NAME
SSVC::Deployer - SSVC Deployer decision (patch application priority)
SYNOPSIS
use SSVC::Deployer;
$ssvc = SSVC::Deployer->new(
exploitation => 'active',
system_exposure => 'open',
automatable => 'yes',
safety_impact => 'catastrophic',
mission_impact => 'mission_failure',
);
# Get the decision
say $ssvc->decision; # immediate
# Get the decision point value
say $ssvc->human_impact; # very_high
# Convert SSVC in JSON in according of SSVC JSON Schema
$json = encode_json($ssvc);
DESCRIPTION
The Deployer decision helps organizations decide the priority with which to apply a patch, or other remediation, for a deployed system.
https://certcc.github.io/SSVC/howto/deployer_tree/
OBJECT-ORIENTED INTERFACE
- $ssvc = SSVC::Deployer->new(%params)
-
Creates a new SSVC::Deployer instance using the provided decision points.
Parameters / Decision Points:
exploitation(required)system_exposure(required)automatable(required)safety_impact(required)mission_impact(required)human_impact(optional), Computed fromsafety_impactandmission_impact
- $ssvc->decision
-
The deployer patch-application priority decision:
defer,scheduled,out_of_cycleorimmediate. - $ssvc->TO_JSON
-
Helper method for JSON modules (JSON, JSON::PP, JSON::XS, Mojo::JSON, etc).
DECISION POINTS
- $ssvc->exploitation
-
The present state of exploitation of the vulnerability.
- $ssvc->system_exposure
-
The accessible attack surface of the affected system or service.
- $ssvc->automatable
-
Can an attacker reliably automate creating exploitation events for this vulnerability?
- $ssvc->safety_impact
-
The safety impact of the vulnerability.
- $ssvc->mission_impact
-
Impact on Mission Essential Functions of the organization.
- $ssvc->human_impact
-
Human Impact, computed from
safety_impactandmission_impact.
SEE ALSO
- [Carnegie Mellon University] SSVC: Stakeholder-Specific Vulnerability Categorization (https://certcc.github.io/SSVC/)
SUPPORT
Bugs / Feature Requests
Please report any bugs or feature requests through the issue tracker at https://github.com/giterlizzi/perl-SSVC/issues. You will be notified automatically of any progress on your issue.
Source Code
This is open source software. The code repository is available for public review and contribution under the terms of the license.
https://github.com/giterlizzi/perl-SSVC
git clone https://github.com/giterlizzi/perl-SSVC.git
AUTHOR
Giuseppe Di Terlizzi <gdt@cpan.org>
LICENSE AND COPYRIGHT
This software is copyright (c) 2025-2026 by Giuseppe Di Terlizzi.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.